// NeoPixel Ring simple sketch (c) 2013 Shae Erisson
// Released under the GPLv3 license to match the rest of the
// Adafruit NeoPixel library

#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
 #include <avr/power.h> // Required for 16 MHz Adafruit Trinket
#endif

// Which pin on the Arduino is connected to the NeoPixels?
#define PIN        6 // On Trinket or Gemma, suggest changing this to 1

// How many NeoPixels are attached to the Arduino?
#define NUMPIXELS 64 // Popular NeoPixel ring size

// When setting up the NeoPixel library, we tell it how many pixels,
// and which pin to use to send signals. Note that for older NeoPixel
// strips you might need to change the third parameter -- see the
// strandtest example for more information on possible values.
Adafruit_NeoPixel pixels(NUMPIXELS, PIN, NEO_GRB + NEO_KHZ800);

#define DELAYVAL 100 // Time (in milliseconds) to pause between pixels

void setup() {
  // These lines are specifically to support the Adafruit Trinket 5V 16 MHz.
  // Any other board, you can remove this part (but no harm leaving it):
#if defined(__AVR_ATtiny85__) && (F_CPU == 16000000)
  clock_prescale_set(clock_div_1);
#endif
  // END of Trinket-specific code.

  pixels.begin(); // INITIALIZE NeoPixel strip object (REQUIRED)
}

int count=0;

void loop() {

  if(count<16) {
    scrollRainbow();
  } else {
    breath(0,80,40);
  }
 // 
 
}


void scrollRainbow() {
  pixels.clear();
  for(int i=0; i<8; i++) { // For each pixel...
    setRow(i, softRainbowColor(count+i));
  }
  pixels.show();
  delay(300);
  count++;
}

void breath(int r, int g, int b){
  int steps = 32;
  pixels.clear();
  for(int i=0; i<8; i++) {
    int t = count%(steps*2);
    if(t > steps) {
      t = steps*2-t;
    }
    setRow(i, pixels.Color(t*r/steps, t*g/steps, t*b/steps));
  }
  pixels.show();
  delay(50);
  count++;
}


void setPixel(int row, int column, uint32_t color) {
  if ((row%2) == 0) {
    pixels.setPixelColor(row*8+column, color);  
  } else {
    pixels.setPixelColor(row*8+7-column, color);
  }
}

void setRow(int row, uint32_t color) {
  for(int j=0; j<8; j++) {
    setPixel(row, j, color);
  }
}

void setColumn(int column, uint32_t color) {
  for(int j=0; j<8; j++) {
    setPixel(j, column, color);
  }
}

uint32_t softRainbowColor(int index) {
  int v=2; 
  
  index = index%24;
  
  if(index >= 0 && index < 8) {
    return pixels.Color(9*v-index*v, index*v+v, v);
  }

  if(index >=8 && index < 16) {
    return pixels.Color(v, 9*v-(index-8)*v, (index-8)*v+v);
  }

  if(index >=16 && index < 24) {
    return pixels.Color((index-16)*v+v, v, 9*v-(index-16)*v);
  }

  return pixels.Color(0, 0, 0);
}
