#include <MyRealTimeClock.h>                         
#include <Wire.h>
#include <Adafruit_SSD1306.h>
#include <Adafruit_GFX.h>

// OLED display TWI address
#define OLED_ADDR   0x3C

MyRealTimeClock myRTC(6, 7, 8);
Adafruit_SSD1306 display(128, 64, &Wire, -1);  
#define countof(a) (sizeof(a) / sizeof(a[0]))
char datestring[20];

void setup()  {      
  Serial.begin(9600);
  Serial.println("To set the timer, type year month day hour minute second dayOfWeek and then press enter");
  setupOLED();
}


void loop()  {                                                                                            
  checkCmdSetting();
  updateDateTimeString();
  Serial.println(datestring);    
  showDateTime();                                       
  delay(900);                                                                    
}       

void checkCmdSetting() {
  while (Serial.available() > 0) {
    int year = Serial.parseInt();
    int month = Serial.parseInt();
    int day = Serial.parseInt();
    int hour = Serial.parseInt();
    int minute = Serial.parseInt();
    int second = Serial.parseInt();
    int dayofweek = Serial.parseInt();

    if (Serial.read() == '\n') {
      myRTC.setDS1302Time(second, minute, hour, dayofweek, day, month, year);
      Serial.print("DateTime set to: ");
      updateDateTimeString();
      Serial.println(datestring);
    }
  }
}

void updateDateTimeString() {
  myRTC.updateTime();   
  snprintf_P(datestring, 
            countof(datestring),
            PSTR("%04u/%02u/%02u %02u:%02u:%02u"),
            myRTC.year,
            myRTC.month,
            myRTC.dayofmonth,
            myRTC.hours,
            myRTC.minutes,
            myRTC.seconds);
}

void setupOLED() {Th
  display.begin(SSD1306_SWITCHCAPVCC, OLED_ADDR);
  display.clearDisplay();
  display.display();
}

void showDateTime() {
  display.clearDisplay();
  int color = myRTC.seconds % 2;
  showDots(color, 0, 0, 128, 12, 2);
  showDots(color, 0, 52, 128, 12, 2);
  
  display.setTextSize(2);
  display.setTextColor(WHITE);
  display.setCursor(2,18);
  display.print(datestring);
  display.display();
}

void showDots(int mode, int sx, int sy, int width, int height, int s) {
  for(int i=sx; i<(sx+width); i++) {
    for(int j=sy; j<(sy+height); j++) {
      int color = (((i-sx) % (s*3) > s) ^ ((j-sy) % (s*3) > s))? mode : 1-mode;
      display.drawPixel(i, j, color);
    }
  }
}
